:Name: printf
:Author: fiachia
:Function: 打印带有颜色的字符串
:Defect: 命令行输出字符|

版本1.0.1:
##########
* 1.带有windows颜色、背景和高亮设置
* 2.带有默认信号设置

版本1.1.1:
##########
* 1.修复bug
* 2.更加贴近于print函数，且支持多个输入
* 3.添加颜色变量，方便简打输入

版本1.1.2:
##########
* 1.修复bug

版本1.1.3:
##########
* 1.修复bug

版本1.1.4:
##########
* 1.修复bug